#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-JuSKcL2x7gvHrvi4XVCcUw
key:                  http-conduit-2.3.9.1-JuSKcL2x7gvHrvi4XVCcUw
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  e65c83e71da2863c2fe3bd5a83f4d0be
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-JuSKcL2x7gvHrvi4XVCcUw
depends:
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    attoparsec-0.14.4-9CcJCC4ORykBmnSiMZ6uwP
    attoparsec-aeson-2.2.0.1-GizRtDqX30r1GIBnmEuU50 base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-534uwm1BQ035a3x29nwuhR
    conduit-extra-1.3.8-1DWgHn4WIu2hT6xloHtnR
    http-client-0.7.19-BV4AT2QZinhAZt9DyDMIrY
    http-client-tls-0.3.6.4-4PkwIHdSyLZEv9DDXogskJ
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9 mtl-2.3.1
    resourcet-1.2.6-5o8OKNGoLEyGu1zh0QIf5q transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

